Achievement

Struct Achievement 

pub struct Achievement<Metadata, Player, State, Trigger> {
    pub id: Uuid,
    pub metadata: Metadata,
    pub audio_file: AudioSource,
    pub evaluator: Box<dyn DynEvaluator<Player, State, Trigger>>,
    pub hot_duration: Option<Duration>,
}
Represents a configured achievement with evaluation logic.

Fields

id: Uuid

Unique ID of the achievement.

metadata: Metadata

Metadata definition of the achievement.

audio_file: AudioSource

Audio file to play when achievement is awarded.

evaluator: Box<dyn DynEvaluator<Player, State, Trigger>>

Evaluation logic for determining if the achievement should be awarded.

hot_duration: Option<Duration>

Optional duration for which the achievement remains “hot”.

Implementations

Source

impl<Metadata, Player, State, Trigger> Achievement<Metadata, Player, State, Trigger>

pub fn evaluate(&self, ctx: &AchievementContext<'_, Player, State, Trigger>)

Evaluates the achievement against the provided context.

Awards the achievement to one or multiple players depending on the evaluation result.