AchievementBuilder

Struct AchievementBuilder 

pub struct AchievementBuilder<Player, State, Trigger, Metadata> { /* private fields */ }
Builder for constructing Achievement instances with typed parameters.

Implementations

Source

impl AchievementBuilder<(), (), (), ()>

pub fn new() -> Self

Source

impl<Player, State, Trigger, Metadata> AchievementBuilder<Player, State, Trigger, Metadata>

pub fn id(self, id: Uuid) -> Self

Sets the unique ID for the achievement.

pub fn evaluator<P, S, T>( self, evaluator: impl IntoDynEvaluator<P, S, T>, ) -> AchievementBuilder<P, S, T, Metadata>

Sets the evaluator that determines when the achievement is awarded.

pub fn metadata<T>( self, metadata: T, ) -> AchievementBuilder<Player, State, Trigger, T>

Sets the metadata associated with the achievement.

pub fn audio_path<P: Into<PathBuf>>(self, audio_path: P) -> Self

Optionally sets a path to audio to play when the achievement is awarded.

pub fn hot_duration(self, hot_duration: Duration) -> Self

Optionally sets a duration for which the achievement remains “hot” after being awarded.

pub fn build( self, ) -> Result<Achievement<Metadata, Player, State, Trigger>, BuilderError>

Attempts to build an achievement, returning an error if required fields are missing.

Errors

Returns BuilderError::MissingField if id or evaluator was not set.