pub struct BloopCollection<Player> { /* private fields */ }Expand description
A collection of bloops with a maximum age threshold.
Automatically prunes bloops which are older than the specified maximum age.
Implementations
Sourceimpl<Player> BloopCollection<Player>
impl<Player> BloopCollection<Player>
Sourcepub fn new(max_age: Duration) -> Self
pub fn new(max_age: Duration) -> Self
Creates an empty collection with the specified maximum age.
Sourcepub fn with_bloops(max_age: Duration, bloops: Vec<Arc<Bloop<Player>>>) -> Self
pub fn with_bloops(max_age: Duration, bloops: Vec<Arc<Bloop<Player>>>) -> Self
Creates a collection pre-populated with bloops, sorted by most recent.