pub struct BloopProvider<Player> { /* private fields */ }Expand description
Provides access to bloops globally and per client, respecting a maximum age.
Implementations
Sourceimpl<Player> BloopProvider<Player>
impl<Player> BloopProvider<Player>
Sourcepub fn with_bloops(max_age: Duration, bloops: Vec<Bloop<Player>>) -> Self
pub fn with_bloops(max_age: Duration, bloops: Vec<Bloop<Player>>) -> Self
Creates a provider initialized with a set of bloops.
Sourcepub fn add(&mut self, bloop: Arc<Bloop<Player>>)
pub fn add(&mut self, bloop: Arc<Bloop<Player>>)
Adds a bloop to the global and client-specific collections.
Sourcepub fn global(&self) -> &BloopCollection<Player>
pub fn global(&self) -> &BloopCollection<Player>
Returns a reference to the global collection of bloops.
Sourcepub fn for_client(&self, client_id: &str) -> &BloopCollection<Player>
pub fn for_client(&self, client_id: &str) -> &BloopCollection<Player>
Returns a reference to the collection of bloops for a specific client.