pub struct ProcessedBloopSinkBuilder<R: BloopRepository> { /* private fields */ }Expand description
Builder for constructing a ProcessedBloopSink.
Implementations
Sourceimpl<R: BloopRepository> ProcessedBloopSinkBuilder<R>
impl<R: BloopRepository> ProcessedBloopSinkBuilder<R>
Sourcepub fn repository(self, repository: R) -> Self
pub fn repository(self, repository: R) -> Self
Sets the repository used by the sink.
Sourcepub fn max_batch_size(self, size: usize) -> Self
pub fn max_batch_size(self, size: usize) -> Self
Sets the maximum number of bloops to buffer before flushing.
Sourcepub fn max_batch_duration(self, duration: Duration) -> Self
pub fn max_batch_duration(self, duration: Duration) -> Self
Sets the maximum duration to wait before flushing the buffered bloops.
Sourcepub fn event_rx(self, event_rx: Receiver<Event>) -> Self
pub fn event_rx(self, event_rx: Receiver<Event>) -> Self
Sets the event receiver from which bloops are received.
Sourcepub fn build(self) -> Result<ProcessedBloopSink<R>, BuilderError>
pub fn build(self) -> Result<ProcessedBloopSink<R>, BuilderError>
Attempts to build the sink, returning an error if any required fields are missing.