DistinctValuesEvaluatorBuilder

Struct DistinctValuesEvaluatorBuilder 

pub struct DistinctValuesEvaluatorBuilder<R, W> { /* private fields */ }
Implementations

Source

impl DistinctValuesEvaluatorBuilder<NoValue, NoValue>

pub fn new() -> Self

Source

impl<W, R> DistinctValuesEvaluatorBuilder<R, W>

pub fn award_all(self) -> Self

Award all involved players instead of just the current player.

Source

impl<W> DistinctValuesEvaluatorBuilder<NoValue, W>

pub fn min_required( self, min_required: usize, ) -> DistinctValuesEvaluatorBuilder<Value<usize>, W>

Set the minimum number of distinct values required to award the achievement.

Source

impl<R> DistinctValuesEvaluatorBuilder<R, NoValue>

pub fn max_window( self, max_window: Duration, ) -> DistinctValuesEvaluatorBuilder<R, Value<Duration>>

Set the maximum time window in which the bloops must have occurred.

Source

impl DistinctValuesEvaluatorBuilder<Value<usize>, Value<Duration>>

pub fn build<Player, State, Trigger, V, E>( self, extract: E, ) -> impl Evaluator<Player, State, Trigger> + Debug
where Player: 'static, State: 'static, Trigger: 'static, E: Fn(&Player) -> ExtractResult<V> + Send + Sync + 'static, V: Eq + Hash + 'static,

Build the evaluator.

pub fn build_with_derived_ctx<Player, State, Trigger, V, C, DC, E>( self, derive_ctx: DC, extract: E, ) -> impl Evaluator<Player, State, Trigger> + Debug
where DC: for<'a> Fn(&'a AchievementContext<'_, Player, State, Trigger>) -> DerivedCtx<'a, C> + Send + Sync + 'static, E: for<'a> Fn(&'a Player, &'a C) -> ExtractResult<V> + Send + Sync + 'static, V: Eq + Hash + 'static,

Build the evaluator with additionally derived context.

The derived context can be used to initially retrieve values from the achievement context and have them available in the extractor.