pub enum AwardMode {
Current,
All,
}Expand description
Which players receive the award when the evaluation passes.
Variants
Current
Award only the current player
All
Award all players whose bloops were involved in completing the collection.