pub enum EvalResult {
AwardSelf,
AwardMultiple(Vec<Uuid>),
NoAward,
}Expand description
Result of evaluating whether an achievement should be awarded.
Variants
AwardSelf
Award the achievement to the evaluating player only.
AwardMultiple(Vec<Uuid>)
Award the achievement to multiple players, identified by UUIDs.
NoAward
Do not award the achievement.