Traits
- Registration
Number Provider - Trait to provide a registration number for a player.
Functions
- build_
predicate_ evaluator - Builds a
crate::evaluator::streak::StreakEvaluatorthat matches registration numbers against a predicated. - build_
projection_ match_ evaluator - Builds a
crate::evaluator::streak::StreakEvaluatorthat matches registration number projections against the project of the current player. - digit_
sum - Calculates the sum of the digits of a number.
- is_
fibonacci - Checks if a number is a Fibonacci number.
- is_
perfect_ square - Checks if a number is a perfect square.
- is_
prime - Checks if a number is prime.