HealthReportSender

Trait HealthReportSender 

pub trait HealthReportSender {
    type Error: Debug + Display + Send + Sync + 'static;

    // Required method
    fn send(
        &mut self,
        report: &HealthReport,
        silent: bool,
    ) -> impl Future<Output = Result<(), Self::Error>> + Send;
}
A trait for sending health reports asynchronously.

Required Associated Types

type Error: Debug + Display + Send + Sync + 'static

Required Methods

fn send( &mut self, report: &HealthReport, silent: bool, ) -> impl Future<Output = Result<(), Self::Error>> + Send

Sends a health report asynchronously.

The report argument is the health report to send. If silent is true, notifications should be suppressed if possible.

Returns Ok(()) on success, or an error of type Self::Error on failure.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors