ClientMessage

Enum ClientMessage 

pub enum ClientMessage {
    ClientHandshake {
        min_version: u8,
        max_version: u8,
    },
    Authentication {
        client_id: String,
        client_secret: String,
        ip_addr: IpAddr,
    },
    Ping,
    Quit,
    Bloop {
        nfc_uid: NfcUid,
    },
    RetrieveAudio {
        achievement_id: Uuid,
    },
    PreloadCheck {
        audio_manifest_hash: Option<DataHash>,
    },
    Unknown(Message),
}
Enum of messages sent from the client to the server.

Variants



ClientHandshake

Handshake message specifying the supported protocol version range.

Fields

min_version: u8
max_version: u8


Authentication

Authentication message including client ID, secret, and IP address.

Fields

client_id: String
client_secret: String
ip_addr: IpAddr


Ping

Ping message (keep-alive).



Quit

Quit message (disconnect).



Bloop

“Bloop” message containing an NFC UID.

Fields

nfc_uid: NfcUid


RetrieveAudio

Request to retrieve audio data associated with an achievement ID.

Fields

achievement_id: Uuid


PreloadCheck

Preload check optionally including a hash of the audio manifest.

Fields

audio_manifest_hash: Option<DataHash>


Unknown(Message)

Unknown or unsupported message variant, carrying raw message data.