PlayerInfo

Trait PlayerInfo 

pub trait PlayerInfo {
    // Required methods
    fn id(&self) -> Uuid;
    fn nfc_uid(&self) -> NfcUid;
    fn total_bloops(&self) -> usize;
    fn awarded_achievements(&self) -> &HashMap<Uuid, DateTime<Utc>>;
}
Provides read-only information about a player.

Required Methods

fn id(&self) -> Uuid

Returns the unique player ID.

fn nfc_uid(&self) -> NfcUid

Returns the player’s NFC UID.

fn total_bloops(&self) -> usize

Returns the total number of bloops the player has collected.

fn awarded_achievements(&self) -> &HashMap<Uuid, DateTime<Utc>>

Returns a reference to the map of awarded achievements and their timestamps.

Implementors