StatisticsServer

Struct StatisticsServer 

pub struct StatisticsServer { /* private fields */ }
A background service that collects statistics and exposes them over HTTP.

Implementations

Source

impl StatisticsServer

pub async fn listen(&mut self) -> Result<(), Error>

Starts the statistics server and begins listening for events and HTTP requests.

This runs the main event loop until the broadcast channel is closed.