Module test_utils

Module test_utils 

Structs

MockPlayer
Represents a mock implementation of a player.
MockPlayerBuilder
Builder for creating test/mock players with configurable properties.
TestCtxBuilder
Builder pattern struct for assembling an achievement test context.
Utc
A utility struct providing a custom UTC clock based on a fixed base time and a monotonic timer to ensure consistent time progression.