pub enum TriggerOccurrence {
Once,
Times(usize),
Duration(Duration),
}Expand description
Specifies how often or for how long a trigger should remain active.
Variants
Once
The trigger can only be used once.
Times(usize)
The trigger can be used a specified number of times.
Duration(Duration)
The trigger remains active for the specified duration.