Struct BloopCollection

pub struct BloopCollection<Player> { /* private fields */ }
A collection of bloops with a maximum age threshold.

Automatically prunes bloops which are older than the specified maximum age.

Implementations

Source

impl<Player> BloopCollection<Player>

pub fn new(max_age: Duration) -> Self

Creates an empty collection with the specified maximum age.

pub fn with_bloops(max_age: Duration, bloops: Vec<Arc<Bloop<Player>>>) -> Self

Creates a collection pre-populated with bloops, sorted by most recent.

pub fn add(&mut self, bloop: Arc<Bloop<Player>>)

Adds a bloop to the collection, pruning old bloops exceeding the max age.

pub fn iter(&self) -> impl Iterator<Item = &Arc<Bloop<Player>>>

Returns an iterator over all bloops in the collection.