pub struct ProcessedBloopSink<R: BloopRepository> { /* private fields */ }Expand description
A sink that buffers processed bloops and persists them in batches.
Implementations
Sourceimpl<R: BloopRepository> ProcessedBloopSink<R>
impl<R: BloopRepository> ProcessedBloopSink<R>
Sourcepub async fn process_events(&mut self)
pub async fn process_events(&mut self)
Processes incoming events, buffering bloops and persisting in batches.