pub struct DistinctValuesEvaluatorBuilder<R, W> { /* private fields */ }Expand description
Builder for DistinctValuesEvaluator.
Implementations
Sourceimpl<W, R> DistinctValuesEvaluatorBuilder<R, W>
impl<W, R> DistinctValuesEvaluatorBuilder<R, W>
Sourceimpl<W> DistinctValuesEvaluatorBuilder<NoValue, W>
impl<W> DistinctValuesEvaluatorBuilder<NoValue, W>
Sourcepub fn min_required(
self,
min_required: usize,
) -> DistinctValuesEvaluatorBuilder<Value<usize>, W>
pub fn min_required( self, min_required: usize, ) -> DistinctValuesEvaluatorBuilder<Value<usize>, W>
Set the minimum number of distinct values required to award the achievement.
Sourceimpl<R> DistinctValuesEvaluatorBuilder<R, NoValue>
impl<R> DistinctValuesEvaluatorBuilder<R, NoValue>
Sourcepub fn max_window(
self,
max_window: Duration,
) -> DistinctValuesEvaluatorBuilder<R, Value<Duration>>
pub fn max_window( self, max_window: Duration, ) -> DistinctValuesEvaluatorBuilder<R, Value<Duration>>
Set the maximum time window in which the bloops must have occurred.
Sourceimpl DistinctValuesEvaluatorBuilder<Value<usize>, Value<Duration>>
impl DistinctValuesEvaluatorBuilder<Value<usize>, Value<Duration>>
Sourcepub fn build<Player, State, Trigger, V, E>(
self,
extract: E,
) -> impl Evaluator<Player, State, Trigger> + Debug
pub fn build<Player, State, Trigger, V, E>( self, extract: E, ) -> impl Evaluator<Player, State, Trigger> + Debug
Build the evaluator.
Sourcepub fn build_with_derived_ctx<Player, State, Trigger, V, C, DC, E>(
self,
derive_ctx: DC,
extract: E,
) -> impl Evaluator<Player, State, Trigger> + Debugwhere
DC: for<'a> Fn(&'a AchievementContext<'_, Player, State, Trigger>) -> DerivedCtx<'a, C> + Send + Sync + 'static,
E: for<'a> Fn(&'a Player, &'a C) -> ExtractResult<V> + Send + Sync + 'static,
V: Eq + Hash + 'static,
pub fn build_with_derived_ctx<Player, State, Trigger, V, C, DC, E>(
self,
derive_ctx: DC,
extract: E,
) -> impl Evaluator<Player, State, Trigger> + Debugwhere
DC: for<'a> Fn(&'a AchievementContext<'_, Player, State, Trigger>) -> DerivedCtx<'a, C> + Send + Sync + 'static,
E: for<'a> Fn(&'a Player, &'a C) -> ExtractResult<V> + Send + Sync + 'static,
V: Eq + Hash + 'static,
Build the evaluator with additionally derived context.
The derived context can be used to initially retrieve values from the achievement context and have them available in the extractor.