pub struct MinBloopsEvaluator { /* private fields */ }Expand description
Evaluates that the player has at least a given number of total bloops.
This evaluator returns true if the total number of bloops associated with
the player meets or exceeds the configured minimum count. It can be used to
gate achievements based on accumulated activity.
Implementations
Sourceimpl MinBloopsEvaluator
impl MinBloopsEvaluator
Sourcepub fn new(min_count: usize) -> Self
pub fn new(min_count: usize) -> Self
Creates a new MinBloopsEvaluator with a given min count.
Examples
use bloop_server_framework::evaluator::min_bloops::MinBloopsEvaluator;
let evaluator = MinBloopsEvaluator::new(10_000);Trait Implementations
Sourceimpl Debug for MinBloopsEvaluator
impl Debug for MinBloopsEvaluator
Sourceimpl<Player: PlayerInfo, Metadata, Trigger> Evaluator<Player, Metadata, Trigger> for MinBloopsEvaluator
impl<Player: PlayerInfo, Metadata, Trigger> Evaluator<Player, Metadata, Trigger> for MinBloopsEvaluator
Sourcefn evaluate(
&self,
ctx: &AchievementContext<'_, Player, Metadata, Trigger>,
) -> impl Into<EvalResult>
fn evaluate( &self, ctx: &AchievementContext<'_, Player, Metadata, Trigger>, ) -> impl Into<EvalResult>
Evaluate the achievement for the given context.