Structs
- Number
Predicate Evaluator - Evaluates if recent bloops meet a numeric property predicate.
- Projection
Match Evaluator - Evaluates whether a number projection of recent players matches that of the current player.
Traits
- Registration
Number Provider - Trait to provide a registration number for a player.
Functions
- digit_
sum - is_
fibonacci - Checks if a number is a Fibonacci number.
- is_
perfect_ square - Checks if a number is a perfect square.
- is_
prime - Checks if a number is prime.