pub enum ServerMessage {
Error(ErrorResponse),
ServerHandshake {
accepted_version: u8,
features: ServerFeatures,
},
AuthenticationAccepted,
Pong,
BloopAccepted {
achievements: Vec<AchievementRecord>,
},
AudioData {
data: Vec<u8>,
},
PreloadMatch,
PreloadMismatch {
audio_manifest_hash: DataHash,
achievements: Vec<AchievementRecord>,
},
Custom(Message),
}Expand description
Enum of messages sent from the server to the client.
Variants
Error(ErrorResponse)
Error response message.
ServerHandshake
Server handshake response with accepted protocol version and features.
AuthenticationAccepted
Authentication was accepted.
Pong
Pong response to client’s ping.
BloopAccepted
Response to a Bloop message containing achievement records.
Fields

achievements: Vec<AchievementRecord>AudioData
Audio data response carrying raw bytes.
PreloadMatch
Indicates preload data matched on the server.
PreloadMismatch
Indicates preload data mismatched, includes hash and achievements.
Custom(Message)
Custom server message.